@@ -1066,6 +1066,10 @@ void Dialog::showEvent(QShowEvent *event)
     if (d->backgroundHints != Dialog::NoBackground) {
         DialogShadows::self()->addWindow(this, d->frameSvgItem->enabledBorders());
     }
+
+    // TODO: Remove this call from other places once we can depend on Qt >= 5.6.1
+    KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+
     QQuickWindow::showEvent(event);
 }
 
@@ -1188,6 +1192,9 @@ void Dialog::componentComplete()
 {
     d->componentComplete = true;
     QQuickWindow::setVisible(d->visible);
+    if (d->visible) {
+        KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+    }
 
     d->updateTheme();
 
@@ -1239,6 +1246,9 @@ void Dialog::setVisible(bool visible)
             setPosition(popupPosition(d->visualParent, size()));
         }
         QQuickWindow::setVisible(visible);
+        if (visible) {
+            KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+        }
         //signal will be emitted and proxied from the QQuickWindow code
     } else {
         emit visibleChangedProxy();
